NameLookup

Trait NameLookup 

pub trait NameLookup {
    // Required methods
    fn cluster_name(&self, cluster_id: &str) -> Option<String>;
    fn replica_name(&self, cluster_id: &str, replica_id: &str) -> Option<String>;
    fn object_name(&self, global_id: &str) -> Option<ObjectName>;
}
Available on crate feature metrics only.
Resolves IDs to their names

Required Methods

fn cluster_name(&self, cluster_id: &str) -> Option<String>

Returns the name of the cluster with the given ID, if it exists.

fn replica_name(&self, cluster_id: &str, replica_id: &str) -> Option<String>

Returns the name of the replica with the given (cluster, replica) IDs.

fn object_name(&self, global_id: &str) -> Option<ObjectName>

Returns the fully-qualified name of the catalog object with the given global ID.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors